macro_rules! error_with {
($logger:expr, $($arg:tt)+) => { ... };
}Expand description
Log an error message using format string syntax with a specific logger
macro_rules! error_with {
($logger:expr, $($arg:tt)+) => { ... };
}Log an error message using format string syntax with a specific logger